@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package Log::Dispatch::File::Stamped; # git description: v0.19-12-g811f456
+package Log::Dispatch::File::Stamped; # git description: v0.20-2-g046d6cc
 # vim: set ts=8 sts=4 sw=4 tw=115 et :
 # ABSTRACT: Logging to date/time stamped files
 # KEYWORDS: log logging output file timestamp date rolling rotate
 
-our $VERSION = '0.20';
+our $VERSION = '0.21';
 
 use File::Basename        qw(fileparse);
 use File::Spec::Functions qw(catfile);
@@ -18,7 +18,7 @@ use Params::ValidationCompiler qw(validation_for);
 
 use Specio::Library::Builtins;
 use Specio::Library::String;
-use Specio::Declare;
+use Specio::Declare 0.48;
 
 use namespace::clean 0.19;
 
@@ -119,7 +119,7 @@ Log::Dispatch::File::Stamped - Logging to date/time stamped files
 
 =head1 VERSION
 
-version 0.20
+version 0.21
 
 =head1 SYNOPSIS
 
